@@ -88,8 +88,7 @@ class H2Protocol(asyncio.Protocol):
         self.free_channels = ChannelPool(1000)
 
     def connection_made(self, transport: asyncio.BaseTransport) -> None:
-        assert isinstance(transport, asyncio.Transport)
-        self.transport = transport
+        self.transport = transport  # type: ignore
         self.conn.initiate_connection()
         self.flush()
 
@@ -180,8 +179,9 @@ class APNsBaseClientProtocol(H2Protocol):
             (":path", "/3/device/%s" % request.device_token),
             ("host", self.APNS_SERVER),
             ("apns-id", request.notification_id),
-            ("apns-topic", self.apns_topic),
         ]
+        apns_topic = request.apns_topic or self.apns_topic
+        headers.append(("apns-topic", apns_topic))
         if request.time_to_live is not None:
             expiration = int(time.time()) + request.time_to_live
             headers.append(("apns-expiration", str(expiration)))
